"use strict";
/*
Language: CoffeeScript
Author: Dmytrii Nagirniak <dnagir@gmail.com>
Contributors: Oleg Efimov <efimovov@gmail.com>, Cédric Néhémie <cedric.nehemie@gmail.com>
Description: CoffeeScript is a programming language that transcompiles to JavaScript. For info about language see http://coffeescript.org/
Category: common, scripting
*/
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var common_1 = require("../common");
var KEYWORDS = {
    keyword: 
    // JS keywords
    'in if for while finally new do return else break catch instanceof throw try this ' +
        'switch continue typeof delete debugger super yield import export from as default await ' +
        // Coffee keywords
        'then unless until loop of by when and or is isnt not',
    literal: 
    // JS literals
    'true false null undefined ' +
        // Coffee literals
        'yes no on off',
    built_in: 'npm require console print module global window document'
};
var JS_IDENT_RE = '[A-Za-z$_][0-9A-Za-z$_]*';
var SUBST = {
    className: 'subst',
    begin: /#\{/, end: /}/,
    keywords: KEYWORDS
};
var EXPRESSIONS = [
    common_1.BINARY_NUMBER_MODE,
    tslib_1.__assign({}, common_1.C_NUMBER_MODE, { starts: { end: '(\\s*/)?', relevance: 0 } }),
    {
        className: 'string',
        variants: [
            {
                begin: /'''/, end: /'''/,
                contains: [common_1.BACKSLASH_ESCAPE]
            },
            {
                begin: /'/, end: /'/,
                contains: [common_1.BACKSLASH_ESCAPE]
            },
            {
                begin: /"""/, end: /"""/,
                contains: [common_1.BACKSLASH_ESCAPE, SUBST]
            },
            {
                begin: /"/, end: /"/,
                contains: [common_1.BACKSLASH_ESCAPE, SUBST]
            }
        ]
    },
    {
        className: 'regexp',
        variants: [
            {
                begin: '///', end: '///',
                contains: [SUBST, common_1.HASH_COMMENT_MODE]
            },
            {
                begin: '//[gim]*',
                relevance: 0
            },
            {
                // regex can't start with space to parse x / 2 / 3 as two divisions
                // regex can't start with *, and it supports an "illegal" in the main mode
                begin: /\/(?![ *])(\\\/|.)*?\/[gim]*(?=\W|$)/
            }
        ]
    },
    {
        begin: '@' + JS_IDENT_RE // relevance booster
    },
    {
        subLanguage: 'javascript',
        excludeBegin: true, excludeEnd: true,
        variants: [
            {
                begin: '```', end: '```',
            },
            {
                begin: '`', end: '`',
            }
        ]
    }
];
SUBST.contains = EXPRESSIONS;
var TITLE = tslib_1.__assign({}, common_1.TITLE_MODE, { begin: JS_IDENT_RE });
var PARAMS_RE = '(\\(.*\\))?\\s*\\B[-=]>';
var PARAMS = {
    className: 'params',
    begin: '\\([^\\(]', returnBegin: true,
    /* We need another contained nameless mode to not have every nested
    pair of parens to be called "params" */
    contains: [{
            begin: /\(/, end: /\)/,
            keywords: KEYWORDS,
            contains: ['self'].concat(EXPRESSIONS)
        }]
};
exports.CoffeeScript = {
    name: 'coffeescript',
    aliases: ['coffee', 'cson', 'iced'],
    keywords: KEYWORDS,
    illegal: /\/\*/,
    contains: EXPRESSIONS.concat([
        common_1.COMMENT('###', '###'),
        common_1.HASH_COMMENT_MODE,
        {
            className: 'function',
            begin: '^\\s*' + JS_IDENT_RE + '\\s*=\\s*' + PARAMS_RE, end: '[-=]>',
            returnBegin: true,
            contains: [TITLE, PARAMS]
        },
        {
            // anonymous function start
            begin: /[:\(,=]\s*/,
            relevance: 0,
            contains: [
                {
                    className: 'function',
                    begin: PARAMS_RE, end: '[-=]>',
                    returnBegin: true,
                    contains: [PARAMS]
                }
            ]
        },
        {
            className: 'class',
            beginKeywords: 'class',
            end: '$',
            illegal: /[:="\[\]]/,
            contains: [
                {
                    beginKeywords: 'extends',
                    endsWithParent: true,
                    illegal: /[:="\[\]]/,
                    contains: [TITLE]
                },
                TITLE
            ]
        },
        {
            begin: JS_IDENT_RE + ':', end: ':',
            returnBegin: true, returnEnd: true,
            relevance: 0
        }
    ])
};
//# sourceMappingURL=coffeescript.js.map