"use strict";
/*
Language: YAML
Author: Stefan Wienert <stwienert@gmail.com>
Requires: ruby.js
Description: YAML (Yet Another Markdown Language)
Category: config
*/
Object.defineProperty(exports, "__esModule", { value: true });
var common_1 = require("../common");
var LITERALS = 'true false yes no null';
var keyPrefix = '^[ \\-]*';
var keyName = '[a-zA-Z_][\\w\\-]*';
var KEY = {
    className: 'attr',
    variants: [
        { begin: keyPrefix + keyName + ":" },
        { begin: keyPrefix + '"' + keyName + '"' + ":" },
        { begin: keyPrefix + "'" + keyName + "'" + ":" }
    ]
};
var TEMPLATE_VARIABLES = {
    className: 'template-variable',
    variants: [
        { begin: '\{\{', end: '\}\}' },
        { begin: '%\{', end: '\}' } // Ruby i18n
    ]
};
var STRING = {
    className: 'string',
    relevance: 0,
    variants: [
        { begin: /'/, end: /'/ },
        { begin: /"/, end: /"/ },
        { begin: /\S+/ }
    ],
    contains: [
        common_1.BACKSLASH_ESCAPE,
        TEMPLATE_VARIABLES
    ]
};
exports.YAML = {
    name: 'yaml',
    case_insensitive: true,
    aliases: ['yml', 'YAML', 'yaml'],
    contains: [
        KEY,
        {
            className: 'meta',
            begin: '^---\s*$',
            relevance: 10
        },
        {
            className: 'string',
            begin: '[\\|>] *$',
            returnEnd: true,
            contains: STRING.contains,
            // very simple termination: next hash key
            end: KEY.variants[0].begin
        },
        {
            begin: '<%[%=-]?', end: '[%-]?%>',
            subLanguage: 'ruby',
            excludeBegin: true,
            excludeEnd: true,
            relevance: 0
        },
        {
            className: 'type',
            begin: '!!' + common_1.UNDERSCORE_IDENT_RE,
        },
        {
            className: 'meta',
            begin: '&' + common_1.UNDERSCORE_IDENT_RE + '$',
        },
        {
            className: 'meta',
            begin: '\\*' + common_1.UNDERSCORE_IDENT_RE + '$'
        },
        {
            className: 'bullet',
            begin: '^ *-',
            relevance: 0
        },
        common_1.HASH_COMMENT_MODE,
        {
            beginKeywords: LITERALS,
            keywords: { literal: LITERALS }
        },
        common_1.C_NUMBER_MODE,
        STRING
    ]
};
//# sourceMappingURL=yaml.js.map